==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/PageSettings/ts/PageSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>PageSettings</name>
    <message>
        <location filename="../PageSettings.js" line="+30"/>
        <source>Printing</source>
        <translatorcomment>--exact match--
--file: MultiPageSettings_pt.ts--
Imprimindo...
Imprimindo
Impressão completa</translatorcomment>
        <translation>Imprimindo</translation>
    </message>
    <message>
        <source>Default Page Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Configurações de página padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para novos desenhos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Printing - Page</source>
        <translation>Imprimindo - Página</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Page</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Página:
Página
Centralize à página</translatorcomment>
        <translation>Página</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Personalizado
Não entidades de dimensão com posições etiqueta personalizada selecionada.</translatorcomment>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Page Orientation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Orientação da página</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Portrait</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Retrato
_Retrato</translatorcomment>
        <translation>Retrato</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Landscape</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Paisagem
Paisagem</translatorcomment>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Paper</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Papel
Papel
Formato do Papel</translatorcomment>
        <translation>Papel</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Paper size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho do papel:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Paper width:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Largura do Papel:</translatorcomment>
        <translation>Largura do Papel:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Paper height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Altura do Papel:</translatorcomment>
        <translation>Altura do Papel:</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Viewport</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Viewport</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Scale:</source>
        <translatorcomment>--ignored colon--
--file: qcadactions_pt.ts--</translatorcomment>
        <translation>&amp;Escala:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Offset X:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Deslocamento X:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Offset Y:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Deslocamento Y:</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Zero-Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto zero</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Miscellaneous</source>
        <translatorcomment>--exact match--
--file: pt.po--
[2300-23FF] Miscelânea Técnica
[2600-26FF] Miscelânea de Símbolos</translatorcomment>
        <translation>Miscelânio</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show paper borders</source>
        <translation>Mostrar bordas da página</translation>
    </message>
    <message>
        <source>Show page borders</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar bordas da página</translation>
    </message>
    <message>
        <source>Show bounding box</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar caixa delimitadora</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/PageSettings/ts/PageSettings_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>PageSettings</name>
    <message>
        <location filename="../PageSettings.js" line="+30"/>
        <source>Printing</source>
        <translatorcomment>--exact match--
--file: MultiPageSettings_pt.ts--
Imprimindo...
Imprimindo
Impressão completa</translatorcomment>
        <translation>Imprimindo</translation>
    </message>
    <message>
        <source>Default Page Settings</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Configurações de página padrão</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Padrões para Novos Desenhos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Printing - Page</source>
        <translation>Imprimindo - Página</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Page</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Página:
Página
Centralize à página</translatorcomment>
        <translation>Página</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Customize..
Personalizado
Não entidades de dimensão com posições etiqueta personalizada selecionada.</translatorcomment>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Page Orientation</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Orientação da Página</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Portrait</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
Retrato
_Retrato</translatorcomment>
        <translation>Retrato</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Landscape</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Paisagem
Paisagem</translatorcomment>
        <translation>Paisagem</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Paper</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
&amp;Papel
Papel
Formato do Papel</translatorcomment>
        <translation>Papel</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Paper size:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tamanho do papel:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Paper width:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Largura do Papel:</translatorcomment>
        <translation>Largura do papel:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Paper height:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Altura do Papel:</translatorcomment>
        <translation>Altura do papel:</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Viewport</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Âncora de Vista</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Scale:</source>
        <translatorcomment>--ignored colon--
--file: qcadactions_pt.ts--</translatorcomment>
        <translation>&amp;Escala:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Offset X:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Offset em X:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Offset Y:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Offset em Y:</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Zero-Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto zero</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Miscellaneous</source>
        <translatorcomment>--exact match--
--file: pt.po--
[2300-23FF] Miscelânea Técnica
[2600-26FF] Miscelânea de Símbolos</translatorcomment>
        <translation>Miscelânea</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show paper borders</source>
        <translation>Exiba as bordas do papel</translation>
    </message>
    <message>
        <source>Show page borders</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar bordas da página</translation>
    </message>
    <message>
        <source>Show bounding box</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Mostrar caixa delimitadora</translation>
    </message>
</context>
</TS>
